@@ -1,4 +1,17 @@
 from __future__ import annotations
+
+import numpy as np
+import math
+from scipy.spatial.transform import Rotation as R
+from numba import njit
+from typing import Union, Tuple, Sequence, Optional
+from dataclasses import dataclass
+
+RotationMatrixLike = Union[Sequence[Sequence[float]], np.ndarray, "RotationMatrix"]
+VectorLike = Union[Sequence[float], np.ndarray, "Vector", "Point"]
+QuaternionTuple = Tuple[float, float, float, float]
+VectorTuple = Tuple[float, float, float]
+
 from .linalg import (
     add_vec_vec,
     cast_vec_to_array,
@@ -10,17 +23,7 @@ from .linalg import (
     norm_L2,
     sub_vec_vec,
 )
-import numpy as np
-import math
-from scipy.spatial.transform import Rotation as R
-from numba import njit
 from .auxiliary import html_table_from_matrix, html_table_from_vector
-from typing import Union, Tuple, Sequence, Optional
-from dataclasses import dataclass
-
-RotationMatrixLike = Union[Sequence[Sequence[float]], np.ndarray, "RotationMatrix"]
-VectorLike = Union[Sequence[float], np.ndarray, "Vector", "Point"]
-QuaternionTuple = Tuple[float, float, float, float]
 
 
 class Frame:
@@ -102,7 +105,7 @@ class Frame:
         p = np.eye(4)
         p[0:3, 0:3] = self._rot
         p[0:3, 3] = self._trans
-        return " ".join(["{:0.12f}".format(i) for i in p.flatten()])
+        return "\n".join([" ".join([f"{i:0.12f}"for i in l]) for l in p])
 
     def euler_angles(self, *args, **kwargs) -> np.ndarray:
         """Frame rotation Euler angles.
@@ -410,7 +413,7 @@ class Vector:
         return obj
 
     def express_in_frame(
-        self, new_frame: Frame, original_frame: Frame = Frame.create_unit_frame()
+        self, new_frame: Frame, original_frame: Optional[Frame] = None
     ) -> Vector:
         """Express this vector in a different frame.
 
@@ -423,6 +426,7 @@ class Vector:
         Returns:
             Vector expressed in `new_frame`.
         """
+
         return express_vector_in_frame(self._a, new_frame, original_frame)
 
     def __repr__(self) -> str:
@@ -549,7 +553,7 @@ class Point:
         return obj
 
     def express_in_frame(
-        self, new_frame, original_frame: Frame = Frame.create_unit_frame()
+        self, new_frame, original_frame: Optional[Frame] = None
     ) -> Point:
         """Express this point in a different frame.
 
@@ -562,6 +566,7 @@ class Point:
         Returns:
             Point expressed in `new_frame`.
         """
+
         return express_point_in_frame(self._a, new_frame, original_frame)
 
     def __repr__(self) -> str:
@@ -849,9 +854,13 @@ def express_point_in_frame(
             _express_point_bare(new_frame._rot, new_frame._trans, point), copy=False
         )
     else:
-        trafo = transformation_between_frames(original_frame, new_frame)
+        new_frame_in_orig_frame = express_frame_in_frame(new_frame, original_frame)
         return Point(
-            (np.asarray(point) - trafo._trans) @ trafo._rot
+            np.array(
+                _express_point_bare(
+                    new_frame_in_orig_frame._rot, new_frame_in_orig_frame._trans, point
+                )
+            )
         )  # multiplication to the right is the same as with transpose to the left
 
 
@@ -875,10 +884,10 @@ def express_points_in_frame(
     if original_frame is None:
         return _express_points_bare(new_frame._rot, new_frame._trans, points)
     else:
-        trafo = transformation_between_frames(original_frame, new_frame)
+        new_frame_in_orig_frame = express_frame_in_frame(new_frame, original_frame)
         return (
-            np.asarray(points) - trafo._trans
-        ) @ trafo._rot  # multiplication to the right is the same as with transpose to the left
+            np.asarray(points) - new_frame_in_orig_frame._trans
+        ) @ new_frame_in_orig_frame._rot  # multiplication to the right is the same as with transpose to the left
 
 
 def express_vector_in_frame(
@@ -901,7 +910,7 @@ def express_vector_in_frame(
     if original_frame is None:
         trafo = new_frame
     else:
-        trafo = transformation_between_frames(original_frame, new_frame)
+        trafo = express_frame_in_frame(new_frame, original_frame)
     return Vector(np.asarray(vector) @ trafo._rot)
 
 
@@ -939,7 +948,7 @@ def _transform_point_bare(rot, trans, p):
 
 
 @njit
-def _express_point_bare(rot, trans, p):
+def _express_point_bare(rot, trans, p) -> VectorTuple:
     return mult_vec_mat(sub_vec_vec(p, trans), rot)
 
 
